@@ -132,10 +132,10 @@ from neptune.internal.operation import (
 from neptune.internal.operation_processors.operation_storage import OperationStorage
 from neptune.internal.utils import base64_decode
 from neptune.internal.utils.generic_attribute_mapper import map_attribute_result_to_value
+from neptune.internal.utils.git import GitInfo
 from neptune.internal.utils.paths import path_to_str
 from neptune.internal.websockets.websockets_factory import WebsocketsFactory
 from neptune.management.exceptions import ObjectNotFound
-from neptune.types.atoms import GitRef
 from neptune.version import version as neptune_client_version
 
 if TYPE_CHECKING:
@@ -316,31 +316,31 @@ class HostedNeptuneBackend(NeptuneBackend):
     def create_run(
         self,
         project_id: UniqueId,
-        git_ref: Optional[GitRef] = None,
+        git_info: Optional[GitInfo] = None,
         custom_run_id: Optional[str] = None,
         notebook_id: Optional[str] = None,
         checkpoint_id: Optional[str] = None,
     ) -> ApiExperiment:
 
-        git_info = (
+        git_info_serialized = (
             {
                 "commit": {
-                    "commitId": git_ref.commit_id,
-                    "message": git_ref.message,
-                    "authorName": git_ref.author_name,
-                    "authorEmail": git_ref.author_email,
-                    "commitDate": git_ref.commit_date,
+                    "commitId": git_info.commit_id,
+                    "message": git_info.message,
+                    "authorName": git_info.author_name,
+                    "authorEmail": git_info.author_email,
+                    "commitDate": git_info.commit_date,
                 },
-                "repositoryDirty": git_ref.dirty,
-                "currentBranch": git_ref.branch,
-                "remotes": git_ref.remotes,
+                "repositoryDirty": git_info.dirty,
+                "currentBranch": git_info.branch,
+                "remotes": git_info.remotes,
             }
-            if git_ref
+            if git_info
             else None
         )
 
         additional_params = {
-            "gitInfo": git_info,
+            "gitInfo": git_info_serialized,
             "customId": custom_run_id,
         }
 
