@@ -110,8 +110,8 @@ from neptune.internal.operation_visitor import OperationVisitor
 from neptune.internal.types.file_types import FileType
 from neptune.internal.utils import base64_decode
 from neptune.internal.utils.generic_attribute_mapper import NoValue
+from neptune.internal.utils.git import GitInfo
 from neptune.internal.utils.paths import path_to_str
-from neptune.metadata_containers import Model
 from neptune.types import (
     Boolean,
     Integer,
@@ -192,7 +192,7 @@ class NeptuneBackendMock(NeptuneBackend):
     def create_run(
         self,
         project_id: UniqueId,
-        git_ref: Optional[GitRef] = None,
+        git_info: Optional[GitInfo] = None,
         custom_run_id: Optional[str] = None,
         notebook_id: Optional[str] = None,
         checkpoint_id: Optional[str] = None,
@@ -200,9 +200,7 @@ class NeptuneBackendMock(NeptuneBackend):
         sys_id = SysId(f"{self.PROJECT_KEY}-{self._next_run}")
         self._next_run += 1
         new_run_id = UniqueId(str(uuid.uuid4()))
-        container = self._create_container(new_run_id, ContainerType.RUN, sys_id=sys_id)
-        if git_ref:
-            container.set(["source_code", "git"], git_ref)
+        self._create_container(new_run_id, ContainerType.RUN, sys_id=sys_id)
         return ApiExperiment(
             id=new_run_id,
             type=ContainerType.RUN,
@@ -268,7 +266,7 @@ class NeptuneBackendMock(NeptuneBackend):
         elif expected_container_type == ContainerType.MODEL:
             return ApiExperiment(
                 id=UniqueId(str(uuid.uuid4())),
-                type=Model.container_type,
+                type=ContainerType.MODEL,
                 sys_id=SysId(container_id.rsplit("/", 1)[-1]),
                 workspace=self.WORKSPACE_NAME,
                 project_name=self.PROJECT_NAME,
